@@ -290,12 +290,12 @@ QString KAboutLicense::spdx() const
     // SPDX licenses are comprised of an identifier (e.g. GPL-2.0), an optional + to denote 'or
     // later versions' and optional ' WITH $exception' to denote standardized exceptions from the
     // core license. As we do not offer exceptions we effectively only return GPL-2.0 or GPL-2.0+,
-    // this may change in the future. To that end the documentation makes no assertations about the
+    // this may change in the future. To that end the documentation makes no assertions about the
     // actual content of the SPDX license expression we return.
     // Expressions can in theory also contain AND, OR and () to build constructs involving more than
     // one license. As this is outside the scope of a single license object we'll ignore this here
     // for now.
-    // The expecation is that the return value is only run through spec-compliant parsers, so this
+    // The expectation is that the return value is only run through spec-compliant parsers, so this
     // can potentially be changed.
 
     auto id = d->spdxID();
@@ -418,7 +418,6 @@ public:
     QList<KAboutPerson> _creditList;
     QList<KAboutPerson> _translatorList;
     QList<KAboutLicense> _licenseList;
-    QString productName;
 #if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
     QString programIconName;
 #endif
@@ -435,6 +434,7 @@ public:
     QByteArray _internalProgramName;
     QByteArray _version;
     QByteArray _bugAddress;
+    QByteArray productName;
 
     static QList<KAboutPerson> parseTranslators(const QString &translatorName, const QString &translatorEmail);
 };
@@ -719,7 +719,7 @@ KAboutData &KAboutData::setOrganizationDomain(const QByteArray &domain)
 
 KAboutData &KAboutData::setProductName(const QByteArray &_productName)
 {
-    d->productName = QString::fromUtf8(_productName.data());
+    d->productName = _productName;
     return *this;
 }
 
@@ -731,11 +731,16 @@ QString KAboutData::componentName() const
 QString KAboutData::productName() const
 {
     if (!d->productName.isEmpty()) {
-        return d->productName;
+        return QString::fromUtf8(d->productName);
     }
     return componentName();
 }
 
+const char *KAboutData::internalProductName() const
+{
+    return d->productName.isEmpty() ? nullptr : d->productName.constData();
+}
+
 QString KAboutData::displayName() const
 {
     if (!d->_displayName.isEmpty()) {
