@@ -13,13 +13,13 @@
 
 #include <kcoreaddons_export.h>
 
+#include <QStringList>
 #include <qnamespace.h>
 
 class QChar;
 class QRegExp;
 class QRegularExpression;
 class QString;
-class QStringList;
 
 /**
  * This namespace contains utility functions for handling strings.
@@ -49,19 +49,18 @@ class QStringList;
  */
 namespace KStringHandler
 {
-
 /** Capitalizes each word in the string
-  * "hello there" becomes "Hello There"        (string)
-  * @param text the text to capitalize
-  * @return the resulting string
-  */
+ * "hello there" becomes "Hello There"        (string)
+ * @param text the text to capitalize
+ * @return the resulting string
+ */
 KCOREADDONS_EXPORT QString capwords(const QString &text);
 
 /** Capitalizes each word in the list
-  * [hello, there] becomes [Hello, There]    (list)
-  * @param list the list to capitalize
-  * @return the resulting list
-  */
+ * [hello, there] becomes [Hello, There]    (list)
+ * @param list the list to capitalize
+ * @return the resulting list
+ */
 KCOREADDONS_EXPORT QStringList capwords(const QStringList &list);
 
 /** Substitute characters at the beginning of a string by "...".
@@ -105,9 +104,7 @@ KCOREADDONS_EXPORT QString rsqueeze(const QString &str, int maxlen = 40);
  * @param max is the maximum number of extractions to perform, or 0.
  * @return A QStringList containing tokens extracted from s.
  */
-KCOREADDONS_EXPORT QStringList perlSplit(const QString &sep,
-        const QString &s,
-        int max = 0);
+KCOREADDONS_EXPORT QStringList perlSplit(const QString &sep, const QString &s, int max = 0);
 
 /**
  * Split a QString into a QStringList in a similar fashion to the static
@@ -126,9 +123,7 @@ KCOREADDONS_EXPORT QStringList perlSplit(const QString &sep,
  * @param max is the maximum number of extractions to perform, or 0.
  * @return A QStringList containing tokens extracted from s.
  */
-KCOREADDONS_EXPORT QStringList perlSplit(const QChar &sep,
-        const QString &s,
-        int max = 0);
+KCOREADDONS_EXPORT QStringList perlSplit(const QChar &sep, const QString &s, int max = 0);
 
 #if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 67)
 /**
@@ -151,10 +146,9 @@ KCOREADDONS_EXPORT QStringList perlSplit(const QChar &sep,
  * @deprecated Since 5.67, use perlSplit(const QRegularExpression &sep,
  * const QString &s, int max = 0) instead.
  */
+KCOREADDONS_EXPORT
 KCOREADDONS_DEPRECATED_VERSION(5, 67, "Use KStringHandler::perlSplit(const QRegularExpression &, const QString &, int)")
-KCOREADDONS_EXPORT QStringList perlSplit(const QRegExp &sep,
-        const QString &s,
-        int max = 0);
+QStringList perlSplit(const QRegExp &sep, const QString &s, int max = 0);
 #endif
 
 /**
@@ -176,8 +170,7 @@ KCOREADDONS_EXPORT QStringList perlSplit(const QRegExp &sep,
  *
  * @since 5.67
  */
-KCOREADDONS_EXPORT QStringList perlSplit(const QRegularExpression &sep,
-                                         const QString &s, int max = 0);
+KCOREADDONS_EXPORT QStringList perlSplit(const QRegularExpression &sep, const QString &s, int max = 0);
 
 /**
  * This method auto-detects URLs in strings, and adds HTML markup to them
