@@ -9,11 +9,11 @@
 #include "ktexttohtml_p.h"
 #include "ktexttohtmlemoticonsinterface.h"
 
-#include <QStringList>
-#include <QFile>
-#include <QRegularExpression>
-#include <QPluginLoader>
 #include <QCoreApplication>
+#include <QFile>
+#include <QPluginLoader>
+#include <QRegularExpression>
+#include <QStringList>
 
 #include <limits.h>
 
@@ -35,7 +35,7 @@ static void loadEmoticonsPlugin()
             QPluginLoader lib(QStringLiteral("kf5/KEmoticonsIntegrationPlugin"));
             QObject *rootObj = lib.instance();
             if (rootObj) {
-                s_emoticonsInterface = rootObj->property(KTEXTTOHTMLEMOTICONS_PROPERTY).value<KTextToHTMLEmoticonsInterface*>();
+                s_emoticonsInterface = rootObj->property(KTEXTTOHTMLEMOTICONS_PROPERTY).value<KTextToHTMLEmoticonsInterface *>();
             }
         }
     }
@@ -44,8 +44,6 @@ static void loadEmoticonsPlugin()
     }
 }
 
-
-
 KTextToHTMLHelper::KTextToHTMLHelper(const QString &plainText, int pos, int maxUrlLen, int maxAddressLen)
     : mText(plainText)
     , mMaxUrlLen(maxUrlLen)
@@ -54,7 +52,7 @@ KTextToHTMLHelper::KTextToHTMLHelper(const QString &plainText, int pos, int maxU
 {
 }
 
-KTextToHTMLEmoticonsInterface* KTextToHTMLHelper::emoticonsInterface() const
+KTextToHTMLEmoticonsInterface *KTextToHTMLHelper::emoticonsInterface() const
 {
     if (!s_emoticonsInterface) {
         loadEmoticonsPlugin();
@@ -73,10 +71,10 @@ QString KTextToHTMLHelper::getEmailAddress()
 
         // determine the local part of the email address
         int start = mPos - 1;
-        while (start >= 0 && mText.at(start).unicode() < 128 &&
-                (mText.at(start).isLetterOrNumber() ||
-                 mText.at(start) == QLatin1Char('@') || // allow @ to find invalid email addresses
-                 allowedSpecialChars.indexOf(mText.at(start)) != -1)) {
+        while (start >= 0 && mText.at(start).unicode() < 128
+               && (mText.at(start).isLetterOrNumber() //
+                   || mText.at(start) == QLatin1Char('@') // allow @ to find invalid email addresses
+                   || allowedSpecialChars.indexOf(mText.at(start)) != -1)) {
             if (mText.at(start) == QLatin1Char('@')) {
                 return QString(); // local part contains '@' -> no email address
             }
@@ -94,16 +92,16 @@ QString KTextToHTMLHelper::getEmailAddress()
         // determine the domain part of the email address
         int dotPos = INT_MAX;
         int end = mPos + 1;
-        while (end < mText.length() &&
-                (mText.at(end).isLetterOrNumber() ||
-                 mText.at(end) == QLatin1Char('@') || // allow @ to find invalid email addresses
-                 mText.at(end) == QLatin1Char('.') ||
-                 mText.at(end) == QLatin1Char('-'))) {
+        while (end < mText.length()
+               && (mText.at(end).isLetterOrNumber() //
+                   || mText.at(end) == QLatin1Char('@') // allow @ to find invalid email addresses
+                   || mText.at(end) == QLatin1Char('.') //
+                   || mText.at(end) == QLatin1Char('-'))) {
             if (mText.at(end) == QLatin1Char('@')) {
                 return QString(); // domain part contains '@' -> no email address
             }
             if (mText.at(end) == QLatin1Char('.')) {
-                dotPos = qMin(dotPos, end);   // remember index of first dot in domain
+                dotPos = qMin(dotPos, end); // remember index of first dot in domain
             }
             ++end;
         }
@@ -145,7 +143,10 @@ QString KTextToHTMLHelper::getPhoneNumber()
     if (match.hasMatch()) {
         auto m = match.captured();
         // check for maximum number of digits (15), see https://en.wikipedia.org/wiki/Telephone_numbering_plan
-        if (std::count_if(m.begin(), m.end(), [](const QChar &c) { return c.isDigit(); }) > 15) {
+        const int count = std::count_if(m.begin(), m.end(), [](const QChar &c) {
+            return c.isDigit();
+        });
+        if (count > 15) {
             return {};
         }
         // only one / is allowed, otherwise we trigger on dates
@@ -210,8 +211,8 @@ bool KTextToHTMLHelper::atUrl() const
     }
 
     const auto segment = mText.midRef(mPos);
-    return
-        segment.startsWith(QLatin1String("http://"))
+    /* clang-format off */
+    return segment.startsWith(QLatin1String("http://"))
         || segment.startsWith(QLatin1String("https://"))
         || segment.startsWith(QLatin1String("vnc://"))
         || segment.startsWith(QLatin1String("fish://"))
@@ -226,28 +227,31 @@ bool KTextToHTMLHelper::atUrl() const
         || segment.startsWith(QLatin1String("news:"))
         || segment.startsWith(QLatin1String("tel:"))
         || segment.startsWith(QLatin1String("xmpp:"));
+    /* clang-format on */
 }
 
 bool KTextToHTMLHelper::isEmptyUrl(const QString &url) const
 {
-    return url.isEmpty() ||
-           url == QLatin1String("http://") ||
-           url == QLatin1String("https://") ||
-           url == QLatin1String("fish://") ||
-           url == QLatin1String("ftp://") ||
-           url == QLatin1String("ftps://") ||
-           url == QLatin1String("sftp://") ||
-           url == QLatin1String("smb://") ||
-           url == QLatin1String("vnc://") ||
-           url == QLatin1String("mailto") ||
-           url == QLatin1String("mailto:") ||
-           url == QLatin1String("www") ||
-           url == QLatin1String("ftp") ||
-           url == QLatin1String("news:") ||
-           url == QLatin1String("news://") ||
-           url == QLatin1String("tel") ||
-           url == QLatin1String("tel:") ||
-           url == QLatin1String("xmpp:");
+    /* clang-format off */
+    return url.isEmpty()
+        || url == QLatin1String("http://")
+        || url == QLatin1String("https://")
+        || url == QLatin1String("fish://")
+        || url == QLatin1String("ftp://")
+        || url == QLatin1String("ftps://")
+        || url == QLatin1String("sftp://")
+        || url == QLatin1String("smb://")
+        || url == QLatin1String("vnc://")
+        || url == QLatin1String("mailto")
+        || url == QLatin1String("mailto:")
+        || url == QLatin1String("www")
+        || url == QLatin1String("ftp")
+        || url == QLatin1String("news:")
+        || url == QLatin1String("news://")
+        || url == QLatin1String("tel")
+        || url == QLatin1String("tel:")
+        || url == QLatin1String("xmpp:");
+    /* clang-format on */
 }
 
 QString KTextToHTMLHelper::getUrl(bool *badurl)
@@ -273,26 +277,30 @@ QString KTextToHTMLHelper::getUrl(bool *badurl)
 
             /*if ( beforeUrl == '(' ) {
               afterUrl = ')';
-            } else */if (beforeUrl == QLatin1Char('[')) {
+            } else */
+            if (beforeUrl == QLatin1Char('[')) {
                 afterUrl = QLatin1Char(']');
             } else if (beforeUrl == QLatin1Char('<')) {
                 afterUrl = QLatin1Char('>');
-            } else if (beforeUrl == QLatin1Char('>')) {   // for e.g. <link>http://.....</link>
+            } else if (beforeUrl == QLatin1Char('>')) { // for e.g. <link>http://.....</link>
                 afterUrl = QLatin1Char('<');
             } else if (beforeUrl == QLatin1Char('"')) {
                 afterUrl = QLatin1Char('"');
             }
         }
-        url.reserve(mMaxUrlLen);    // avoid allocs
+        url.reserve(mMaxUrlLen); // avoid allocs
         int start = mPos;
         bool previousCharIsSpace = false;
         bool previousCharIsADoubleQuote = false;
         bool previousIsAnAnchor = false;
-        while ((mPos < mText.length()) &&
-                (mText.at(mPos).isPrint() || mText.at(mPos).isSpace()) &&
-                ((afterUrl.isNull() && !mText.at(mPos).isSpace()) ||
-                 (!afterUrl.isNull() && mText.at(mPos) != afterUrl))) {
-            if (!previousCharIsSpace && (mText.at(mPos) == QLatin1Char('<')) && ((mPos + 1) < mText.length())) {
+        /* clang-format off */
+        while (mPos < mText.length() //
+               && (mText.at(mPos).isPrint() || mText.at(mPos).isSpace())
+               && ((afterUrl.isNull() && !mText.at(mPos).isSpace())
+                   || (!afterUrl.isNull() && mText.at(mPos) != afterUrl))) {
+            if (!previousCharIsSpace
+                && mText.at(mPos) == QLatin1Char('<')
+                && (mPos + 1) < mText.length()) { /* clang-format on */
                 // Fix Bug #346132: allow "http://www.foo.bar<http://foo.bar/>"
                 // < inside a URL is not allowed, however there is a test which
                 // checks that "http://some<Host>/path" should be allowed
@@ -327,7 +335,7 @@ QString KTextToHTMLHelper::getUrl(bool *badurl)
                 }
                 previousCharIsSpace = false;
                 if (mText.at(mPos) == QLatin1Char('>') && previousCharIsADoubleQuote) {
-                    //it's an invalid url
+                    // it's an invalid url
                     if (badurl) {
                         *badurl = true;
                     }
@@ -410,31 +418,13 @@ QString KTextToHTMLHelper::highlightedText()
             case '/':
                 return QLatin1String("<i>/") + match.capturedRef(1) + QLatin1String("/</i>");
             case '-':
-                return QLatin1String("<strike>-") + match.capturedRef(1) + QLatin1String("-</strike>");
+                return QLatin1String("<s>-") + match.capturedRef(1) + QLatin1String("-</s>");
             }
         }
     }
     return QString();
 }
 
-
-QString KTextToHTMLHelper::pngToDataUrl(const QString &iconPath) const
-{
-    if (iconPath.isEmpty()) {
-        return QString();
-    }
-
-    QFile pngFile(iconPath);
-    if (!pngFile.open(QIODevice::ReadOnly | QIODevice::Unbuffered)) {
-        return QString();
-    }
-
-    QByteArray ba = pngFile.readAll();
-    pngFile.close();
-    return QLatin1String("data:image/png;base64,") + QLatin1String(ba.toBase64().constData());
-}
-
-
 QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::Options &flags, int maxUrlLen, int maxAddressLen)
 {
     KTextToHTMLHelper helper(plainText, 0, maxUrlLen, maxAddressLen);
@@ -445,14 +435,12 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
     int x;
     bool startOfLine = true;
 
-    for (helper.mPos = 0, x = 0; helper.mPos < helper.mText.length();
-            ++helper.mPos, ++x) {
+    for (helper.mPos = 0, x = 0; helper.mPos < helper.mText.length(); ++helper.mPos, ++x) {
         ch = helper.mText.at(helper.mPos);
         if (flags & PreserveSpaces) {
             if (ch == QLatin1Char(' ')) {
                 if (helper.mPos + 1 < helper.mText.length()) {
                     if (helper.mText.at(helper.mPos + 1) != QLatin1Char(' ')) {
-
                         // A single space, make it breaking if not at the start or end of the line
                         const bool endOfLine = helper.mText.at(helper.mPos + 1) == QLatin1Char('\n');
                         if (!startOfLine && !endOfLine) {
@@ -461,7 +449,6 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
                             result += QLatin1String("&nbsp;");
                         }
                     } else {
-
                         // Whitespace of more than one space, make it all non-breaking
                         while (helper.mPos < helper.mText.length() && helper.mText.at(helper.mPos) == QLatin1Char(' ')) {
                             result += QLatin1String("&nbsp;");
@@ -553,8 +540,7 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
 
                     // remove the local part from the result (as '&'s have been expanded to
                     // &amp; we have to take care of the 4 additional characters per '&')
-                    result.truncate(result.length() -
-                                    len - (localPart.count(QLatin1Char('&')) * 4));
+                    result.truncate(result.length() - len - (localPart.count(QLatin1Char('&')) * 4));
                     x -= len;
 
                     result += QLatin1String("<a href=\"mailto:") + str + QLatin1String("\">") + str + QLatin1String("</a>");
@@ -583,17 +569,14 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
     }
 
     if (flags & ReplaceSmileys) {
-        const QStringList exclude = {
-            QStringLiteral("(c)"), QStringLiteral("(C)"), QStringLiteral("&gt;:-("), QStringLiteral("&gt;:("),
-            QStringLiteral("(B)"), QStringLiteral("(b)"), QStringLiteral("(P)"), QStringLiteral("(p)"),
-            QStringLiteral("(O)"), QStringLiteral("(o)"), QStringLiteral("(D)"), QStringLiteral("(d)"),
-            QStringLiteral("(E)"), QStringLiteral("(e)"), QStringLiteral("(K)"), QStringLiteral("(k)"),
-            QStringLiteral("(I)"), QStringLiteral("(i)"), QStringLiteral("(L)"), QStringLiteral("(l)"),
-            QStringLiteral("(8)"), QStringLiteral("(T)"), QStringLiteral("(t)"), QStringLiteral("(G)"),
-            QStringLiteral("(g)"), QStringLiteral("(F)"), QStringLiteral("(f)"), QStringLiteral("(H)"),
-            QStringLiteral("8)"), QStringLiteral("(N)"), QStringLiteral("(n)"), QStringLiteral("(Y)"),
-            QStringLiteral("(y)"), QStringLiteral("(U)"), QStringLiteral("(u)"), QStringLiteral("(W)"),
-            QStringLiteral("(w)"), QStringLiteral("(6)")};
+        const QStringList exclude = {QStringLiteral("(c)"), QStringLiteral("(C)"), QStringLiteral("&gt;:-("), QStringLiteral("&gt;:("), QStringLiteral("(B)"),
+                                     QStringLiteral("(b)"), QStringLiteral("(P)"), QStringLiteral("(p)"),     QStringLiteral("(O)"),    QStringLiteral("(o)"),
+                                     QStringLiteral("(D)"), QStringLiteral("(d)"), QStringLiteral("(E)"),     QStringLiteral("(e)"),    QStringLiteral("(K)"),
+                                     QStringLiteral("(k)"), QStringLiteral("(I)"), QStringLiteral("(i)"),     QStringLiteral("(L)"),    QStringLiteral("(l)"),
+                                     QStringLiteral("(8)"), QStringLiteral("(T)"), QStringLiteral("(t)"),     QStringLiteral("(G)"),    QStringLiteral("(g)"),
+                                     QStringLiteral("(F)"), QStringLiteral("(f)"), QStringLiteral("(H)"),     QStringLiteral("8)"),     QStringLiteral("(N)"),
+                                     QStringLiteral("(n)"), QStringLiteral("(Y)"), QStringLiteral("(y)"),     QStringLiteral("(U)"),    QStringLiteral("(u)"),
+                                     QStringLiteral("(W)"), QStringLiteral("(w)"), QStringLiteral("(6)")};
 
         result = helper.emoticonsInterface()->parseEmoticons(result, true, exclude);
     }
